==> portal-new-2.0.11-sources.jar: com/gtis/portal/util/CommonUtils.java <==
package com.gtis.portal.util;

import com.alibaba.fastjson.JSON;
import com.gtis.config.AppConfig;
import com.gtis.fileCenter.model.Node;
import com.gtis.fileCenter.service.NodeService;
import com.gtis.plat.service.SysStuffService;
import com.gtis.plat.vo.UserInfo;
import com.gtis.portal.entity.PfStuffConfig;
import com.gtis.portal.entity.PfUser;
import com.gtis.portal.model.Ztree;
import com.gtis.portal.service.PfStuffConfigService;
import com.gtis.portal.service.PfUserService;
import com.gtis.web.SessionUtil;
import freemarker.cache.StringTemplateLoader;
import freemarker.template.Configuration;
import freemarker.template.Template;
import freemarker.template.TemplateException;
import org.apache.commons.lang.StringUtils;
import org.springframework.core.io.Resource;
import org.springframework.core.io.UrlResource;

import java.io.*;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @文件说明
 * @作者 deery
 * @创建日期 上午 9:58
 * @版本号 V 1.0
 */
public class CommonUtils {
    //首页综合事务中，各模块的配置数据
    public static Map urlMap;

    //工作流新建时，默认工作流名称的初始化信息
    public static Map defaultWINameMap;

    public static Object readJsonFile(String path) throws Exception {
        if(StringUtils.isNotBlank(path)){
            File file = new File(path);
            if (path.startsWith("zip") || path.startsWith("file") || path.startsWith("jar")) { // 当class文件在war中时，返回"zip:D:/ ..."样的路径
                Resource resource = new UrlResource(path);
                file = resource.getFile();
            }else {
                file = new File(path);
            }
            if(file.exists()){
                BufferedReader bufferedReader=null;
                StringBuffer config = new StringBuffer();
                try {
                    bufferedReader = new BufferedReader(new InputStreamReader(new FileInputStream(file), "UTF-8"));
                    String tmp=null;
                    while ((tmp=bufferedReader.readLine())!=null){
                        config.append(tmp);
                    }
                }finally {
                    if(bufferedReader!=null)
                        bufferedReader.close();
                }
                if(StringUtils.isNotBlank(config.toString())){
                    return JSON.parse(config.toString());
                }
            }else{
                System.out.println("文件不存在："+path);
            }
        }
        return null;
    }

    public static String getEgovhomeConfigFilePath(String project)throws Exception{
        //System.out.println(AppConfig.getEgovHome());
        //System.out.println(AppConfig.getProperty("egov.conf"));
        //file:/D:/tomcat/apache-tomcat-onemap/tomcat-7.0.23-x32-std/egov-home/std/
        //file:/D:/tomcat/apache-tomcat-onemap/tomcat-7.0.23-x32-std/egov-home/std/conf/
        String egovHomePath = AppConfig.getProperty("config.reload."+project+".path");
        egovHomePath = RequestUtils.initOptProperties(egovHomePath);
        if (StringUtils.isNotBlank(egovHomePath)){
            return egovHomePath + "/" + project+"/application.properties";
        }else{
            String path = AppConfig.getProperty("egov.conf");
            path = java.net.URLDecoder.decode(path, "UTF-8");
            path = path.replace("file:/", "");
            String filePath = path;
            if (StringUtils.equalsIgnoreCase("egov",project)){
                filePath += "egov.properties";
            }else if (StringUtils.equalsIgnoreCase("gis",project)){
                filePath += "gis.properties";
            }else {
                filePath += project+"/application.properties";
            }
            filePath = RequestUtils.initOptProperties(filePath);
            return filePath;
        }
    }

    public static File getEgovhomeConfigFile(String project)throws Exception{
        String filePath = getEgovhomeConfigFilePath(project);
        File file = new File(filePath);
        if (file.exists() && file.isFile()){
            return file;
        }
        return null;
    }

    /**
     * 获取egovhome下所有的系统配置文件夹及根目录下的配置文件，只处理properties配置文件
     * @return
     * @throws Exception
     */
    public static List<String> getEgovhomeConfigFileList()throws Exception{
        List<String> fileList = new ArrayList<String>();
        String path = AppConfig.getProperty("egov.conf");
        path = java.net.URLDecoder.decode(path, "UTF-8");
        path = path.replace("file:/", "");
        File dir = new File(path);
        if (dir.exists()){
            dir.listFiles();
            //如果是目录，则：
            if(dir.isDirectory()){
                //打印当前目录的路径
                //System.out.println(dir);
                //获取该目录下的所有文件和目录组成的File数组
                File[] files = dir.listFiles();
                //递归遍历每一个子文件
                for(File file : files){
                    String fileName = file.getName();
                    if (file.isDirectory()){
                        if(fileName.matches("^[A-Za-z]+$")){
                            fileList.add(fileName);
                        }
                    }else {
                        String prefix=fileName.substring(fileName.lastIndexOf(".")+1);
                        if (StringUtils.equalsIgnoreCase(prefix,"properties")){
                            fileName = StringUtils.split(fileName,".")[0];
                            if(fileName.matches("^[A-Za-z]+$")){
                                fileList.add(0,fileName);
                            }
                        }
                    }
                }
            }
        }
        int egovIndex = fileList.indexOf("egov");
        fileList.remove(egovIndex);
        fileList.add(0,"egov");
        return fileList;
    }

    /**
     * 获得工作流定义中的附件类型(初始化文件中心附件文件夹)
     * @param nodeService
     * @param stuffConfigService
     * @param workflowDefinitionId
     * @param fileCenterNodeId
     */
    public static void initWorkflowFileCenter(NodeService nodeService, PfStuffConfigService stuffConfigService, String workflowDefinitionId, int fileCenterNodeId){
        List<Node> nodeChiles = nodeService.getChildNodes(fileCenterNodeId);
        if (nodeChiles == null || nodeChiles.size() <= 0){
            //获得工作流定义中的附件类型，用于待办任务打开时，初始化待办任务的附件管理页面
            List<PfStuffConfig> configList = stuffConfigService.getListByWfdId(workflowDefinitionId);
            if (configList != null && configList.size() > 0){
                LinkedHashMap<String,Ztree> stuffTreeMap = new LinkedHashMap<String, Ztree>();
                for (int i = 0; i < configList.size(); i++) {
                    PfStuffConfig configTmp =  configList.get(i);

                    PfStuffConfig stuff = new PfStuffConfig();
                    stuff.setStuffId(configTmp.getStuffId());
                    stuff.setProId(configTmp.getProId());
                    stuff.setStuffName(configTmp.getStuffName());

                    Ztree tree = toZtree(stuff);
                    stuffTreeMap.put(tree.getId(),tree);
                }
                Ztree root = new Ztree();
                root.setId("treeroot");
                root.setName("根节点");
                root.setKz3(fileCenterNodeId);
                for (Ztree tree : stuffTreeMap.values()) {
                    if (tree.getPid() != null) {
                        Ztree ztree = stuffTreeMap.get(tree.getPid());
                        if (ztree != null) {
                            ztree.addChild(tree);
                        }else {
                            tree.setPid("treeroot");
                            root.addChild(tree);
                        }
                    }else {
                        tree.setPid("treeroot");
                        root.addChild(tree);
                    }
                }

                if (root.getChildren() != null && root.getChildren().size() > 0){
                    for (int i = 0; i < root.getChildren().size(); i++) {
                        createFileTree(root,nodeService);
                    }
                }
            }
        }
    }

    private static Ztree toZtree(PfStuffConfig stuff) {
        Ztree tree = new Ztree();
        tree.setId(stuff.getStuffId());
        tree.setName(stuff.getStuffName());
        if(stuff.getProId()==null){
            tree.setPid("treeroot");
        }else{
            tree.setPid(StringUtils.trimToNull(stuff.getProId()));
        }
        return tree;
    }

    public static void createFileTree(Ztree parent,NodeService nodeService){
        if (parent.getChildren() != null && parent.getChildren().size() > 0){
            for (int i = 0; i < parent.getChildren().size(); i++) {
                Ztree tree = parent.getChildren().get(i);
                Node stuffNode = nodeService.getNode(parent.getKz3(),tree.getName(),true);
                //用xh字段临时代替文件中心节点id，用于下面获取父节点id的调用
                tree.setKz3(stuffNode.getId());
                createFileTree(tree,nodeService);
                parent.getChildren().set(i,tree);
            }
        }
    }

    /**
     * 检查是否有对应的独立版本的首页文件夹
     * @param version
     * @return
     */
    public static boolean checkHasIndexVersion(String version){
        if (StringUtils.isNotBlank(version)){
            String path = System.getProperty("user.dir");
            path = path.replace("\\bin", "\\webapps") + "\\portal";
            File file = new File(path+"\\WEB-INF\\views\\index\\zhsw\\"+version);
            if (file.exists()){
                return true;
            }
        }
        return false;
    }
    /**
     * 检查是否有对应的独立版本的任务中心页面
     * @param version
     * @return
     */
    public static boolean checkHasTaskVersion(String version){
        if (StringUtils.isNotBlank(version)){
            String path = System.getProperty("user.dir");
            path = path.replace("\\bin", "\\webapps") + "\\portal";
            File file = new File(path+"\\WEB-INF\\views\\"+version+"\\task\\");
            if (file.exists()){
                return true;
            }
        }
        return false;
    }

    public static String freemarkerProcess(Map input, String templateStr) {
        if (StringUtils.isNotBlank(templateStr) && StringUtils.contains(templateStr,"$")){
            StringTemplateLoader stringLoader = new StringTemplateLoader();
            String template = "content";
            stringLoader.putTemplate(template, templateStr);
            Configuration cfg = new Configuration();
            cfg.setTemplateLoader(stringLoader);
            try {
                Template templateCon = cfg.getTemplate(template);
                StringWriter writer = new StringWriter();
                templateCon.process(input, writer);
                return writer.toString();
            } catch (IOException e) {
                e.printStackTrace();
            } catch (TemplateException e) {
                e.printStackTrace();
            }
        }
        return templateStr;
    }

    /**
     * 解析url参数，将参数转为map对象，之后通过freemarker方式，将url中的变量转换为对应的值
     * @param urlParamStr
     * @param url
     * @return
     */
    public static String initUrlParam(String urlParamStr,String url){
        //解析url参数，将参数转为map对象，之后通过freemarker方式，将url中的变量转换为对应的值
        String params = urlParamStr;
        if (StringUtils.contains(params,"?")){
            params = StringUtils.substringAfter(urlParamStr,"?");
        }
        Map<String,String> paramMap = new HashMap<String,String>();
        String[] param =  params.split("&");
        for(String keyvalue:param){
            String[] pair = keyvalue.split("=");
            if(pair.length==2 && !StringUtils.contains(pair[1],"$")){
                paramMap.put(pair[0], pair[1]);
            }
        }
        return freemarkerProcess(paramMap,url);
    }

    public static String initCurUserUrlParam(){
        String curUserParam = "";
        try {
            if (AppConfig.getBooleanProperty("portal.resource.url.addUsername",false)){
                String username = "";
                if (SessionUtil.getCurrentUser() != null){
                    username = SessionUtil.getCurrentUser().getUsername();
                }
                curUserParam += "&username="+username;
            }
            if (AppConfig.getBooleanProperty("portal.resource.url.addRole",false)){
                String roleId = "";
                if (SessionUtil.getCurrentUser().getLstRole() != null && !SessionUtil.getCurrentUser().getLstRole().isEmpty()){
                    roleId = SessionUtil.getCurrentUser().getLstRole().get(0).getRoleId();
                }
                curUserParam += "&role="+roleId;
                curUserParam += "&roles="+SessionUtil.getCurrentUser().getRoleIds();
            }
            if (AppConfig.getBooleanProperty("portal.resource.url.addXzqdm",false)){
                String xzqdm = "";
                if (SessionUtil.getCurrentUser().getLstOragn() != null && !SessionUtil.getCurrentUser().getLstOragn().isEmpty()){
                    xzqdm = SessionUtil.getCurrentUser().getLstOragn().get(0).getRegionCode();
                }
                curUserParam += "&xzqdm="+xzqdm;
            }
        }catch (Exception ex){

        }
        return curUserParam;
    }

    public static HashMap initCurUserUrlMap(PfUserService pfUserService){
        HashMap curUserParam = new HashMap();
        try {
            if (SessionUtil.getCurrentUser() != null){
                UserInfo userInfo = SessionUtil.getCurrentUser();
                PfUser pfUser = pfUserService.findById(userInfo.getId());
                curUserParam.put("userid",pfUser.getUserId());
                curUserParam.put("username",pfUser.getUserName());
                curUserParam.put("loginname",pfUser.getLoginName());
                if (userInfo.getLstRole() != null && !userInfo.getLstRole().isEmpty()){
                    curUserParam.put("role",userInfo.getLstRole().get(0).getRoleId());
                    curUserParam.put("roles",userInfo.getRoleIds());
                }

                if (userInfo.getLstOragn() != null && !userInfo.getLstOragn().isEmpty()){
                    curUserParam.put("organ",userInfo.getLstOragn().get(0).getOrganId());
                    curUserParam.put("xzqdm",userInfo.getLstOragn().get(0).getRegionCode());
                }
            }
        }catch (Exception ex){
        }
        return curUserParam;
    }

    /**
     * 去除字符串中的换行符、占位符
     * @param str
     * @return
     */
    public static String removeBlankLine(String str){
        Pattern p = Pattern.compile("\\s*|\t|\r|\n");
        Matcher m = p.matcher(str);
        return m.replaceAll("");
    }
}

==> portal-new-2.0.12.2-sources.jar: com/gtis/portal/util/CommonUtils.java <==
package com.gtis.portal.util;

import com.alibaba.fastjson.JSON;
import com.gtis.config.AppConfig;
import com.gtis.fileCenter.model.Node;
import com.gtis.fileCenter.service.NodeService;
import com.gtis.plat.service.SysStuffService;
import com.gtis.plat.vo.PfRoleVo;
import com.gtis.plat.vo.UserInfo;
import com.gtis.portal.entity.PfStuffConfig;
import com.gtis.portal.entity.PfUser;
import com.gtis.portal.model.Ztree;
import com.gtis.portal.service.PfStuffConfigService;
import com.gtis.portal.service.PfUserService;
import com.gtis.web.SessionUtil;
import freemarker.cache.StringTemplateLoader;
import freemarker.template.Configuration;
import freemarker.template.Template;
import freemarker.template.TemplateException;
import org.apache.commons.lang.StringUtils;
import org.springframework.core.io.Resource;
import org.springframework.core.io.UrlResource;

import java.io.*;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @文件说明
 * @作者 deery
 * @创建日期 上午 9:58
 * @版本号 V 1.0
 */
public class CommonUtils {
    //首页综合事务中，各模块的配置数据
    public static Map urlMap;

    //首页的待办事项提醒及其菜单项配置
    public static Map indexRightTopMenuMap;

    //工作流新建时，默认工作流名称的初始化信息
    public static Map defaultWINameMap;

    public static Object readJsonFile(String path) throws Exception {
        if(StringUtils.isNotBlank(path)){
            File file = new File(path);
            if (path.startsWith("zip") || path.startsWith("file") || path.startsWith("jar")) { // 当class文件在war中时，返回"zip:D:/ ..."样的路径
                Resource resource = new UrlResource(path);
                file = resource.getFile();
            }else {
                file = new File(path);
            }
            if(file.exists()){
                BufferedReader bufferedReader=null;
                StringBuffer config = new StringBuffer();
                try {
                    bufferedReader = new BufferedReader(new InputStreamReader(new FileInputStream(file), "UTF-8"));
                    String tmp=null;
                    while ((tmp=bufferedReader.readLine())!=null){
                        config.append(tmp);
                    }
                }finally {
                    if(bufferedReader!=null)
                        bufferedReader.close();
                }
                if(StringUtils.isNotBlank(config.toString())){
                    return JSON.parse(config.toString());
                }
            }else{
                System.out.println("文件不存在："+path);
            }
        }
        return null;
    }

    public static String getEgovhomeConfigFilePath(String project)throws Exception{
        //System.out.println(AppConfig.getEgovHome());
        //System.out.println(AppConfig.getProperty("egov.conf"));
        //file:/D:/tomcat/apache-tomcat-onemap/tomcat-7.0.23-x32-std/egov-home/std/
        //file:/D:/tomcat/apache-tomcat-onemap/tomcat-7.0.23-x32-std/egov-home/std/conf/
        String egovHomePath = AppConfig.getProperty("config.reload."+project+".path");
        egovHomePath = RequestUtils.initOptProperties(egovHomePath);
        if (StringUtils.isNotBlank(egovHomePath)){
            return egovHomePath + "/" + project+"/application.properties";
        }else{
            String path = AppConfig.getProperty("egov.conf");
            path = java.net.URLDecoder.decode(path, "UTF-8");
            path = path.replace("file:/", "");
            String filePath = path;
            if (StringUtils.equalsIgnoreCase("egov",project)){
                filePath += "egov.properties";
            }else if (StringUtils.equalsIgnoreCase("gis",project)){
                filePath += "gis.properties";
            }else {
                filePath += project+"/application.properties";
            }
            filePath = RequestUtils.initOptProperties(filePath);
            return filePath;
        }
    }

    public static File getEgovhomeConfigFile(String project)throws Exception{
        String filePath = getEgovhomeConfigFilePath(project);
        File file = new File(filePath);
        if (file.exists() && file.isFile()){
            return file;
        }
        return null;
    }

    /**
     * 获取egovhome下所有的系统配置文件夹及根目录下的配置文件，只处理properties配置文件
     * @return
     * @throws Exception
     */
    public static List<String> getEgovhomeConfigFileList()throws Exception{
        List<String> fileList = new ArrayList<String>();
        String path = AppConfig.getProperty("egov.conf");
        path = java.net.URLDecoder.decode(path, "UTF-8");
        path = path.replace("file:/", "");
        File dir = new File(path);
        if (dir.exists()){
            dir.listFiles();
            //如果是目录，则：
            if(dir.isDirectory()){
                //打印当前目录的路径
                //System.out.println(dir);
                //获取该目录下的所有文件和目录组成的File数组
                File[] files = dir.listFiles();
                //递归遍历每一个子文件
                for(File file : files){
                    String fileName = file.getName();
                    if (file.isDirectory()){
                        if(fileName.matches("^[A-Za-z]+$")){
                            fileList.add(fileName);
                        }
                    }else {
                        String prefix=fileName.substring(fileName.lastIndexOf(".")+1);
                        if (StringUtils.equalsIgnoreCase(prefix,"properties")){
                            fileName = StringUtils.split(fileName,".")[0];
                            if(fileName.matches("^[A-Za-z]+$")){
                                fileList.add(0,fileName);
                            }
                        }
                    }
                }
            }
        }
        int egovIndex = fileList.indexOf("egov");
        fileList.remove(egovIndex);
        fileList.add(0,"egov");
        return fileList;
    }

    /**
     * 获得工作流定义中的附件类型(初始化文件中心附件文件夹)
     * @param nodeService
     * @param stuffConfigService
     * @param workflowDefinitionId
     * @param fileCenterNodeId
     */
    public static void initWorkflowFileCenter(NodeService nodeService, PfStuffConfigService stuffConfigService, String workflowDefinitionId, int fileCenterNodeId){
        List<Node> nodeChiles = nodeService.getChildNodes(fileCenterNodeId);
        if (nodeChiles == null || nodeChiles.size() <= 0){
            //获得工作流定义中的附件类型，用于待办任务打开时，初始化待办任务的附件管理页面
            List<PfStuffConfig> configList = stuffConfigService.getListByWfdId(workflowDefinitionId);
            if (configList != null && configList.size() > 0){
                LinkedHashMap<String,Ztree> stuffTreeMap = new LinkedHashMap<String, Ztree>();
                for (int i = 0; i < configList.size(); i++) {
                    PfStuffConfig configTmp =  configList.get(i);

                    PfStuffConfig stuff = new PfStuffConfig();
                    stuff.setStuffId(configTmp.getStuffId());
                    stuff.setProId(configTmp.getProId());
                    stuff.setStuffName(configTmp.getStuffName());

                    Ztree tree = toZtree(stuff);
                    stuffTreeMap.put(tree.getId(),tree);
                }
                Ztree root = new Ztree();
                root.setId("treeroot");
                root.setName("根节点");
                root.setKz3(fileCenterNodeId);
                for (Ztree tree : stuffTreeMap.values()) {
                    if (tree.getPid() != null) {
                        Ztree ztree = stuffTreeMap.get(tree.getPid());
                        if (ztree != null) {
                            ztree.addChild(tree);
                        }else {
                            tree.setPid("treeroot");
                            root.addChild(tree);
                        }
                    }else {
                        tree.setPid("treeroot");
                        root.addChild(tree);
                    }
                }

                if (root.getChildren() != null && root.getChildren().size() > 0){
                    for (int i = 0; i < root.getChildren().size(); i++) {
                        createFileTree(root,nodeService);
                    }
                }
            }
        }
    }

    private static Ztree toZtree(PfStuffConfig stuff) {
        Ztree tree = new Ztree();
        tree.setId(stuff.getStuffId());
        tree.setName(stuff.getStuffName());
        if(stuff.getProId()==null){
            tree.setPid("treeroot");
        }else{
            tree.setPid(StringUtils.trimToNull(stuff.getProId()));
        }
        return tree;
    }

    public static void createFileTree(Ztree parent,NodeService nodeService){
        if (parent.getChildren() != null && parent.getChildren().size() > 0){
            for (int i = 0; i < parent.getChildren().size(); i++) {
                Ztree tree = parent.getChildren().get(i);
                Node stuffNode = nodeService.getNode(parent.getKz3(),tree.getName(),true);
                //用xh字段临时代替文件中心节点id，用于下面获取父节点id的调用
                tree.setKz3(stuffNode.getId());
                createFileTree(tree,nodeService);
                parent.getChildren().set(i,tree);
            }
        }
    }

    /**
     * 检查是否有对应的独立版本的首页文件夹
     * @param version
     * @return
     */
    public static boolean checkHasIndexVersion(String version){
        if (StringUtils.isNotBlank(version)){
            String path = System.getProperty("user.dir");
            path = path.replace("\\bin", "\\webapps") + "\\portal";
            File file = new File(path+"\\WEB-INF\\views\\index\\zhsw\\"+version);
            if (file.exists()){
                return true;
            }
        }
        return false;
    }
    /**
     * 检查是否有对应的独立版本的任务中心页面
     * @param version
     * @return
     */
    public static boolean checkHasTaskVersion(String version){
        if (StringUtils.isNotBlank(version)){
            String path = System.getProperty("user.dir");
            path = path.replace("\\bin", "\\webapps") + "\\portal";
            File file = new File(path+"\\WEB-INF\\views\\"+version+"\\task\\");
            if (file.exists()){
                return true;
            }
        }
        return false;
    }

    public static boolean checkHasTaskCenterVersion(String version){
        if (StringUtils.isNotBlank(version)){
            String path = System.getProperty("user.dir");
            path = path.replace("\\bin", "\\webapps") + "\\portal";
            File file = new File(path+"\\WEB-INF\\views\\task\\"+version);
            if (file.exists()){
                return true;
            }
        }
        return false;
    }

    public static String freemarkerProcess(Map input, String templateStr) {
        if (StringUtils.isNotBlank(templateStr) && StringUtils.contains(templateStr,"$")){
            StringTemplateLoader stringLoader = new StringTemplateLoader();
            String template = "content";
            stringLoader.putTemplate(template, templateStr);
            Configuration cfg = new Configuration();
            cfg.setTemplateLoader(stringLoader);
            try {
                Template templateCon = cfg.getTemplate(template);
                StringWriter writer = new StringWriter();
                templateCon.process(input, writer);
                return writer.toString();
            } catch (IOException e) {
                e.printStackTrace();
            } catch (TemplateException e) {
                e.printStackTrace();
            }
        }
        return templateStr;
    }

    /**
     * 解析url参数，将参数转为map对象，之后通过freemarker方式，将url中的变量转换为对应的值
     * @param urlParamStr
     * @param url
     * @return
     */
    public static String initUrlParam(String urlParamStr,String url){
        //解析url参数，将参数转为map对象，之后通过freemarker方式，将url中的变量转换为对应的值
        String params = urlParamStr;
        if (StringUtils.contains(params,"?")){
            params = StringUtils.substringAfter(urlParamStr,"?");
        }
        Map<String,String> paramMap = new HashMap<String,String>();
        String[] param =  params.split("&");
        for(String keyvalue:param){
            String[] pair = keyvalue.split("=");
            if(pair.length==2 && !StringUtils.contains(pair[1],"$")){
                paramMap.put(pair[0], pair[1]);
            }
        }
        return freemarkerProcess(paramMap,url);
    }

    public static String initCurUserUrlParam(){
        String curUserParam = "";
        try {
            if (AppConfig.getBooleanProperty("portal.resource.url.addUsername",false)){
                String username = "";
                if (SessionUtil.getCurrentUser() != null){
                    username = SessionUtil.getCurrentUser().getUsername();
                }
                curUserParam += "&username="+username;
            }
            if (AppConfig.getBooleanProperty("portal.resource.url.addRole",false)){
                String roleId = "";
                if (SessionUtil.getCurrentUser().getLstRole() != null && !SessionUtil.getCurrentUser().getLstRole().isEmpty()){
                    roleId = SessionUtil.getCurrentUser().getLstRole().get(0).getRoleId();
                }
                curUserParam += "&role="+roleId;
                curUserParam += "&roles="+SessionUtil.getCurrentUser().getRoleIds();
            }
            if (AppConfig.getBooleanProperty("portal.resource.url.addXzqdm",false)){
                String xzqdm = "";
                if (SessionUtil.getCurrentUser().getLstOragn() != null && !SessionUtil.getCurrentUser().getLstOragn().isEmpty()){
                    xzqdm = SessionUtil.getCurrentUser().getLstOragn().get(0).getRegionCode();
                }
                curUserParam += "&xzqdm="+xzqdm;
            }
        }catch (Exception ex){

        }
        return curUserParam;
    }

    public static HashMap initCurUserUrlMap(PfUserService pfUserService){
        HashMap curUserParam = new HashMap();
        try {
            if (SessionUtil.getCurrentUser() != null){
                UserInfo userInfo = SessionUtil.getCurrentUser();
                PfUser pfUser = pfUserService.findById(userInfo.getId());
                curUserParam.put("userid",pfUser.getUserId());
                curUserParam.put("username",pfUser.getUserName());
                curUserParam.put("loginname",pfUser.getLoginName());
                if (userInfo.getLstRole() != null && !userInfo.getLstRole().isEmpty()){
                    curUserParam.put("role",userInfo.getLstRole().get(0).getRoleId());
                    curUserParam.put("roles",userInfo.getRoleIds());
                }

                if (userInfo.getLstOragn() != null && !userInfo.getLstOragn().isEmpty()){
                    curUserParam.put("organ",userInfo.getLstOragn().get(0).getOrganId());
                    curUserParam.put("xzqdm",userInfo.getLstOragn().get(0).getRegionCode());
                }
            }
        }catch (Exception ex){
        }
        return curUserParam;
    }

    /**
     * 去除字符串中的换行符、占位符
     * @param str
     * @return
     */
    public static String removeBlankLine(String str){
        Pattern p = Pattern.compile("\\s*|\t|\r|\n");
        Matcher m = p.matcher(str);
        return m.replaceAll("");
    }

    /**
     * 获取字符串中的整数部分
     * @param str
     * @return
     */
    public static String getIntegerStr(String str){
        String numberRegEx = "[^0-9]";
        Pattern pattern = Pattern.compile(numberRegEx);
        Matcher matcher = pattern.matcher(str);
        String result = matcher.replaceAll("");
        return result;
    }
    /**
     * 获取字符串中的数字部分
     * @param str
     * @return
     */
    public static String getNumberStr(String str){
        String numberRegEx = "([^(\\d|\\.)])";
        Pattern pattern = Pattern.compile(numberRegEx);
        Matcher matcher = pattern.matcher(str);
        String result = matcher.replaceAll("");
        return result;
    }
}
